aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRaúl Porcel <armin76@gentoo.org>2013-08-17 19:13:22 +0000
committerRaúl Porcel <armin76@gentoo.org>2013-08-17 19:13:22 +0000
commitb7a016e9ca3f91441f76774a4ecebfb346f954b1 (patch)
treea1fdc81199e9c21d5a64b48621cc973a6018a786 /scripts
parentUse the variant function for the generic latest-stage3.txt (diff)
downloadreleng-b7a016e9ca3f91441f76774a4ecebfb346f954b1.tar.gz
releng-b7a016e9ca3f91441f76774a4ecebfb346f954b1.tar.bz2
releng-b7a016e9ca3f91441f76774a4ecebfb346f954b1.zip
Do not use current-stage3 symlink on arm/hppa/s390/sh since releases are pushed with different datestamp and therefore current-stage3 only links to the latest that was pushed
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/copy_buildsync.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/copy_buildsync.sh b/scripts/copy_buildsync.sh
index 5c4ac37d..39f7e193 100755
--- a/scripts/copy_buildsync.sh
+++ b/scripts/copy_buildsync.sh
@@ -78,9 +78,9 @@ for ARCH in $ARCHES; do
# In the new variant preserve code there is a better way to do this
#echo -e "${stage3_list}" |awk '{print $3}' |grep "$latest_stage3_date" >>${OUT_STAGE3}
rm -f current-stage3
# The "latest stage3" concept doesn't apply to the arm variants
# that are pushed on different days of the week.
- if [[ ! $(echo ${outdir} | grep arm) ]]; then
+ if [[ ! $(echo ${outdir} | egrep 'arm|hppa|ppc|s390|sh') ]]; then
ln -sf "$latest_stage3_date" current-stage3
fi
fi
@@ -78,9 +78,9 @@ for ARCH in $ARCHES; do
#echo -e "${stage3_list}" |awk '{print $3}' |grep "$latest_stage3_date" >>${OUT_STAGE3}
rm -f current-stage3
- # The "latest stage3" concept doesn't apply to the arm variants
+ # The "latest stage3" concept doesn't apply to the arm/hppa/s390/sh variants
# that are pushed on different days of the week.